==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Dokumenta ni mogoče ustvariti",
"You don't have permission to rename this document" => "Ni ustreznih dovoljenj za preimenovanje tega dokumenta ...",
"Directory saved successfully." => "Mapa je uspešno shranjena.",
"An error occurred while changing directory." => "Med spreminjanjem mape je prišlo do napake.",
"Saved" => "Shranjeno",
"Format filter server is down or misconfigured" => "Strežnik filtriranja je nedejaven, ali pa ni pravilno nastavljen",
"Conversion failed. Check log for details." => "Pretvarjanje je spodletelo. Preverite dnevniški zapis za več podrobnosti.",
"Saving..." => "Poteka shranjevanje ...",
"Failed to load documents." => "Nalaganje dokumentov je spodletelo.",
"No documents were found. Upload or create a document to get started!" => "Ni najdenih dokumentov. Ustvarite ga ali pa pošljite obstoječega v oblak.",
"No connection to server. Trying to reconnect." => "Ni povezave s strežnikom. Poskus povezave bo ponovljen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Odhod s strani v načinu urejevalnika lahko vpliva na shranjevanje podatkov. Priporočljivo je raje uporabiti gumb za 'zapiranje' okna.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Nalaganje dokumenta je spodletelo. Preverite, ali ga je mogoče odpreti v zunanjem urejevalniku datotek odt. Do napake je lahko prišlo tudi, če je datoteka izbrisana, ali pa ni več v souporabi.",
"Save" => "Shrani",
"Loading documents..." => "Nalaganje dokumentov ...",
"'.' is an invalid file name." => "'.' je neveljavno ime datoteke.",
"File name cannot be empty." => "Ime datoteke ne sme biti prazno polje.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neveljavno ime; znaki '\\', '/', '<', '>', ':', '\"', '|', '?' in '*' niso dovoljeni.",
"Align Left" => "Poravnaj levo",
"Alignment" => "Poravnava",
"Align Right" => "Poravnaj desno",
"Annotate" => "Zabeleži",
"Background" => "Ozadje",
"Bold" => "Krepko",
"Bottom" => "Spodaj",
"Cancel" => "Prekliči",
"Center" => "Sredina",
"Clone" => "Kloniraj",
"Clone this Style" => "Kloniraj slog",
"Close" => "Zapri",
"Color" => "Barva",
"Create" => "Ustvari",
"Decrease Indent" => "Zmanjšaj zamik",
"Default Style" => "Privzet slog",
"Delete" => "Izbriši",
"Family" => "Družina",
"Font" => "Pisava",
"Font Effects" => "Učinki pisave",
"Format" => "Zapis",
"Increase Indent" => "Povečaj zamik",
"Insert Image" => "Vstavi sliko",
"Invite Members" => "Povabi druge uporabnike",
"Italic" => "Ležeče",
"Justified" => "Poravnano",
"Justify" => "Poravnaj",
"Left" => "Levo",
"Loading" => "Nalaganje",
"Members" => "Člani",
"New Name:" => "Novo ime:",
"OK" => "V redu",
"Open" => "Odpri",
"Options" => "Možnosti",
"Paragraph..." => "Odstavek ...",
"Paragraph Styles" => "Slog odstavka",
"Redo" => "Ponovno uveljavi",
"Right" => "Desno",
"Size" => "Velikost",
"Spacing" => "Razmik",
"Strikethrough" => "Prečrtano",
"Style" => "Slog",
"Text" => "Besedilo",
"Top" => "Zgoraj",
"Underline" => "Podčrtano",
"Undo" => "Razveljavi",
"Unknown Author" => "Neznan avtor",
"Shared" => "V souporabi",
"Error" => "Napaka",
"Error while sharing" => "Napaka med souporabo",
"Error while unsharing" => "Napaka med odstranjevanjem souporabe",
"Error while changing permissions" => "Napaka med spreminjanjem dovoljenj",
"Shared with you and the group {group} by {owner}" => "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
"Shared with you by {owner}" => "V souporabi z vami. Lastnik je {owner}.",
"Share" => "Souporaba",
"Share link" => "Povezava za souporabo",
"The public link will expire no later than {days} days after it is created" => "Javna povezava bo potekla {days} dni po ustvarjanju.",
"Link" => "Povezava",
"Password protect" => "Zaščiti z geslom",
"Password" => "Geslo",
"Choose a password for the public link" => "Izberite geslo za javno povezavo",
"Allow editing" => "Dovoli urejanje",
"Email link to person" => "Posreduj povezavo po elektronski pošti",
"Send" => "Pošlji",
"Set expiration date" => "Nastavi datum preteka",
"Expiration" => "Datum preteka",
"Expiration date" => "Datum preteka",
"Adding user..." => "Dodajanje uporabnika ...",
"group" => "skupina",
"remote" => "oddaljeno",
"Resharing is not allowed" => "Nadaljnja souporaba ni dovoljena",
"Shared in {item} with {user}" => "V souporabi v {item} z uporabnikom {user}",
"Unshare" => "Prekini souporabo",
"notify by email" => "obvesti po elektronski pošti",
"can share" => "lahko omogoči souporabo",
"can edit" => "lahko ureja",
"access control" => "nadzor dostopa",
"create" => "ustvari",
"change" => "sprememba",
"delete" => "izbriši",
"Password protected" => "Zaščiteno z geslom",
"Error unsetting expiration date" => "Napaka brisanja datuma preteka",
"Error setting expiration date" => "Napaka nastavljanja datuma preteka",
"Sending ..." => "Pošiljanje ...",
"Email sent" => "Elektronska pošta je poslana",
"Warning" => "Opozorilo",
"Edit" => "Uredi",
"guest" => "gost",
"MS Word support (requires openOffice/libreOffice)" => "Podpora za MS Word (zahteva namestitev OpenOffice/LibreOffice)",
"Local" => "Krajevno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "OpenOffice oziroma LibreOffice je nameščen na strežniku. Pot to izvedljive datoteke je podana preko možnosti preview_libreoffice_path v datoteki config.php",
"External" => "Zunanje",
"openOffice/libreOffice is installed on external server running a format filter server" => "Pisarniški paket OpenOffice.org oziroma LibreOffice je nameščen na zunanjem strežniku z zagnanim strežnikom filtra za odpiranje pisarniških datotek.",
"Disabled" => "Onemogočeno",
"No MS Word support" => "Ni podpore za MS Word",
"scheme://domain.tld[:port]" => "shema://domena.tld[:vrata]",
"Server URL" => "Naslov URL strežnika",
"Apply and test" => "Uveljavi in preizkusi",
"New document" => "Nov dokument",
"Upload (max. %s)" => "Pošiljanje (omejitev %s)",
"Upload" => "Pošlji",
"Save new documents to" => "Shrani nove dokumente v",
"Wrong password. Please retry." => "Napačno geslo. Poskusite znova.",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Povezava je pretekla ali pa ni nikoli obstajala. Za več podrobnosti stopite v stik z osebo, ki naj bi vam jo poslala.",
"Advanced feature-set" => "Napredne zmožnosti",
"(Unstable)" => "(nestabilno)"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Dokumenta ni mogoče ustvariti",
"You don't have permission to rename this document" => "Ni ustreznih dovoljenj za preimenovanje tega dokumenta ...",
"Directory saved successfully." => "Mapa je uspešno shranjena.",
"An error occurred while changing directory." => "Med spreminjanjem mape je prišlo do napake.",
"Saved" => "Shranjeno",
"Format filter server is down or misconfigured" => "Strežnik filtriranja je nedejaven, ali pa ni pravilno nastavljen",
"Conversion failed. Check log for details." => "Pretvarjanje je spodletelo. Preverite dnevniški zapis za več podrobnosti.",
"Saving..." => "Poteka shranjevanje ...",
"Failed to load documents." => "Nalaganje dokumentov je spodletelo.",
"No documents were found. Upload or create a document to get started!" => "Ni najdenih dokumentov. Ustvarite ga ali pa pošljite obstoječega v oblak.",
"No connection to server. Trying to reconnect." => "Ni povezave s strežnikom. Poskus povezave bo ponovljen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Odhod s strani v načinu urejevalnika lahko vpliva na shranjevanje podatkov. Priporočljivo je raje uporabiti gumb za 'zapiranje' okna.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Nalaganje dokumenta je spodletelo. Preverite, ali ga je mogoče odpreti v zunanjem urejevalniku datotek odt. Do napake je lahko prišlo tudi, če je datoteka izbrisana, ali pa ni več v souporabi.",
"Save" => "Shrani",
"Loading documents..." => "Nalaganje dokumentov ...",
"'.' is an invalid file name." => "'.' je neveljavno ime datoteke.",
"File name cannot be empty." => "Ime datoteke ne sme biti prazno polje.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neveljavno ime; znaki '\\', '/', '<', '>', ':', '\"', '|', '?' in '*' niso dovoljeni.",
"Align Left" => "Poravnaj levo",
"Alignment" => "Poravnava",
"Align Right" => "Poravnaj desno",
"Annotate" => "Zabeleži",
"Background" => "Ozadje",
"Bold" => "Krepko",
"Bottom" => "Spodaj",
"Cancel" => "Prekliči",
"Center" => "Sredina",
"Clone" => "Kloniraj",
"Clone this Style" => "Kloniraj slog",
"Close" => "Zapri",
"Color" => "Barva",
"Create" => "Ustvari",
"Decrease Indent" => "Zmanjšaj zamik",
"Default Style" => "Privzet slog",
"Delete" => "Izbriši",
"Family" => "Družina",
"Font" => "Pisava",
"Font Effects" => "Učinki pisave",
"Format" => "Zapis",
"Increase Indent" => "Povečaj zamik",
"Insert Image" => "Vstavi sliko",
"Invite Members" => "Povabi druge uporabnike",
"Italic" => "Ležeče",
"Justified" => "Poravnano",
"Justify" => "Poravnaj",
"Left" => "Levo",
"Loading" => "Nalaganje",
"Members" => "Člani",
"New Name:" => "Novo ime:",
"OK" => "V redu",
"Open" => "Odpri",
"Options" => "Možnosti",
"Paragraph..." => "Odstavek ...",
"Paragraph Styles" => "Slog odstavka",
"Redo" => "Ponovno uveljavi",
"Right" => "Desno",
"Size" => "Velikost",
"Spacing" => "Razmik",
"Strikethrough" => "Prečrtano",
"Style" => "Slog",
"Text" => "Besedilo",
"Top" => "Zgoraj",
"Underline" => "Podčrtano",
"Undo" => "Razveljavi",
"Unknown Author" => "Neznan avtor",
"Shared" => "V souporabi",
"Error" => "Napaka",
"Error while sharing" => "Napaka med souporabo",
"Error while unsharing" => "Napaka med odstranjevanjem souporabe",
"Error while changing permissions" => "Napaka med spreminjanjem dovoljenj",
"Shared with you and the group {group} by {owner}" => "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
"Shared with you by {owner}" => "V souporabi z vami. Lastnik je {owner}.",
"Share with users or groups …" => "Souporaba z uporabniki ali skupinami ...",
"Share with users, groups or remote users …" => "Souporaba z usporabniki, skupinami ali zunanjimi uporabniki ...",
"Share" => "Souporaba",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Soupraba z ljudmi v drugih ownCloud oblakih v formatu uporabnik@domena.si/owncloud",
"Share link" => "Povezava za souporabo",
"The public link will expire no later than {days} days after it is created" => "Javna povezava bo potekla {days} dni po ustvarjanju.",
"Link" => "Povezava",
"Password protect" => "Zaščiti z geslom",
"Password" => "Geslo",
"Choose a password for the public link" => "Izberite geslo za javno povezavo",
"Allow editing" => "Dovoli urejanje",
"Email link to person" => "Posreduj povezavo po elektronski pošti",
"Send" => "Pošlji",
"Set expiration date" => "Nastavi datum preteka",
"Expiration" => "Datum preteka",
"Expiration date" => "Datum preteka",
"An error occured. Please try again" => "Prišlo je do napake. Poskusite znova.",
"Adding user..." => "Dodajanje uporabnika ...",
"group" => "skupina",
"remote" => "oddaljeno",
"Resharing is not allowed" => "Nadaljnja souporaba ni dovoljena",
"Shared in {item} with {user}" => "V souporabi v {item} z uporabnikom {user}",
"Unshare" => "Prekini souporabo",
"notify by email" => "obvesti po elektronski pošti",
"can share" => "lahko omogoči souporabo",
"can edit" => "lahko ureja",
"access control" => "nadzor dostopa",
"create" => "ustvari",
"change" => "spremeni",
"delete" => "izbriši",
"Password protected" => "Zaščiteno z geslom",
"Error unsetting expiration date" => "Napaka brisanja datuma preteka",
"Error setting expiration date" => "Napaka nastavljanja datuma preteka",
"Sending ..." => "Pošiljanje ...",
"Email sent" => "Elektronska pošta je poslana",
"Warning" => "Opozorilo",
"Edit" => "Uredi",
"guest" => "gost",
"MS Word support (requires openOffice/libreOffice)" => "Podpora za MS Word (zahteva namestitev OpenOffice/LibreOffice)",
"Local" => "Krajevno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "OpenOffice oziroma LibreOffice je nameščen na strežniku. Pot to izvedljive datoteke je podana preko možnosti preview_libreoffice_path v datoteki config.php",
"External" => "Zunanje",
"openOffice/libreOffice is installed on external server running a format filter server" => "Pisarniški paket OpenOffice.org oziroma LibreOffice je nameščen na zunanjem strežniku z zagnanim strežnikom filtra za odpiranje pisarniških datotek.",
"Disabled" => "Onemogočeno",
"No MS Word support" => "Ni podpore za MS Word",
"scheme://domain.tld[:port]" => "shema://domena.tld[:vrata]",
"Server URL" => "Naslov URL strežnika",
"Apply and test" => "Uveljavi in preizkusi",
"New document" => "Nov dokument",
"Upload (max. %s)" => "Pošiljanje (omejitev %s)",
"Upload" => "Pošlji",
"Save new documents to" => "Shrani nove dokumente v",
"Wrong password. Please retry." => "Napačno geslo. Poskusite znova.",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Povezava je pretekla ali pa ni nikoli obstajala. Za več podrobnosti stopite v stik z osebo, ki naj bi vam jo poslala.",
"Advanced feature-set" => "Napredne zmožnosti",
"(Unstable)" => "(nestabilno)"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
